==> joynr-1.21.4.tgz: package/joynr/provider/ProviderEvent.js <==
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const BroadcastOutputParameters_1 = __importDefault(require("./BroadcastOutputParameters"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
const SubscriptionUtil = __importStar(require("../dispatching/subscription/util/SubscriptionUtil"));
class ProviderEvent {
    /**
     * Constructor of ProviderEvent object that is used in the generation of provider objects
     *
     * @constructor
     *
     * @param settings the settings for this provider event
     * @param settings.eventName the name of the event
     * @param settings.selective true if the broadcast is selective
     * @param settings.outputParameterProperties the output parameter names and types
     * @param settings.filterSettings the filter settings
     */
    constructor(settings) {
        this.callbacks = [];
        this.filters = [];
        this.settings = settings;
        this.selective = settings.selective;
    }
    /**
     * @param filterParametersInput an object containing a map filterParameters
     */
    checkFilterParameters(filterParametersInput) {
        const filterParameters = filterParametersInput || {};
        return SubscriptionUtil.checkFilterParameters(this.settings.filterSettings, filterParameters.filterParameters, this.settings.eventName);
    }
    createBroadcastOutputParameters() {
        return new BroadcastOutputParameters_1.default(this.settings.outputParameterProperties);
    }
    /**
     * if this event is fired the applications should call this function with the new
     * output parameters which causes the publication containing the values to be
     * sent to all subscribers.
     *
     * @param broadcastOutputParameters the broadcast output parameters
     * @param [partitions] - the partitions to be used for multicasts
     * @throws {Error} if partitions contains invalid characters
     */
    fire(broadcastOutputParameters, partitions) {
        SubscriptionUtil.validatePartitions(partitions);
        // the UtilInternal.fire method accepts exactly one argument for the callback
        const data = {
            broadcastOutputParameters,
            filters: this.filters,
            partitions: partitions || []
        };
        UtilInternal.fire(this.callbacks, data);
    }
    /**
     * Registers an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#unregisterObserver
     */
    registerObserver(observer) {
        this.callbacks.push(observer);
    }
    /**
     * Unregisters an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#registerObserver
     */
    unregisterObserver(observer) {
        UtilInternal.removeElementFromArray(this.callbacks, observer);
    }
    /**
     * Registers a filter
     *
     * @param filter the callback object that executes the filtering
     * @see ProviderEvent#deleteBroadcastFilter
     */
    addBroadcastFilter(filter) {
        this.filters.push(filter);
    }
    /**
     * Unregisters an Observer for value changes
     *
     * @param filter the callback object that executes the filtering
     * @see ProviderEvent#addBroadcastFilter
     */
    deleteBroadcastFilter(filter) {
        UtilInternal.removeElementFromArray(this.filters, filter);
    }
}
module.exports = ProviderEvent;

==> joynr-1.21.7.tgz: package/joynr/provider/ProviderEvent.js <==
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const BroadcastOutputParameters_1 = __importDefault(require("./BroadcastOutputParameters"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
const SubscriptionUtil = __importStar(require("../dispatching/subscription/util/SubscriptionUtil"));
class ProviderEvent {
    /**
     * Constructor of ProviderEvent object that is used in the generation of provider objects
     *
     * @constructor
     *
     * @param settings the settings for this provider event
     * @param settings.eventName the name of the event
     * @param settings.selective true if the broadcast is selective
     * @param settings.outputParameterProperties the output parameter names and types
     * @param settings.filterSettings the filter settings
     */
    constructor(settings) {
        this.callbacks = [];
        this.filters = [];
        this.settings = settings;
        this.selective = settings.selective;
    }
    /**
     * @param filterParametersInput an object containing a map filterParameters
     */
    checkFilterParameters(filterParametersInput) {
        const filterParameters = filterParametersInput || {};
        return SubscriptionUtil.checkFilterParameters(this.settings.filterSettings, filterParameters.filterParameters, this.settings.eventName);
    }
    createBroadcastOutputParameters() {
        return new BroadcastOutputParameters_1.default(this.settings.outputParameterProperties);
    }
    /**
     * if this event is fired the applications should call this function with the new
     * output parameters which causes the publication containing the values to be
     * sent to all subscribers.
     *
     * @param broadcastOutputParameters the broadcast output parameters
     * @param [partitions] - the partitions to be used for multicasts
     * @throws {Error} if partitions contains invalid characters
     */
    fire(broadcastOutputParameters, partitions) {
        SubscriptionUtil.validatePartitions(partitions);
        // the UtilInternal.fire method accepts exactly one argument for the callback
        const data = {
            broadcastOutputParameters,
            filters: this.filters,
            partitions: partitions || []
        };
        UtilInternal.fire(this.callbacks, data);
    }
    /**
     * Registers an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#unregisterObserver
     */
    registerObserver(observer) {
        this.callbacks.push(observer);
    }
    /**
     * Unregisters an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#registerObserver
     */
    unregisterObserver(observer) {
        UtilInternal.removeElementFromArray(this.callbacks, observer);
    }
    /**
     * Registers a filter
     *
     * @param filter the callback object with a filter function that executes the filtering
     * @see ProviderEvent#deleteBroadcastFilter
     */
    addBroadcastFilter(filter) {
        this.filters.push(filter);
    }
    /**
     * Unregisters an Observer for value changes
     *
     * @param filter the to be removed callback object with a filter function that executes the filtering
     * @see ProviderEvent#addBroadcastFilter
     */
    deleteBroadcastFilter(filter) {
        UtilInternal.removeElementFromArray(this.filters, filter);
    }
}
module.exports = ProviderEvent;
